Module dialog

Module dialog 

The Dialog API module allows you to show messages and prompt for file paths.

Enums

DialogSelection
Response
Result of opening a file dialog

Functions

ask
Displays a dialog with a message and an optional title with a “yes” and a “no” button
message
Displays a message dialog
pick_folder
Open pick folder dialog
save_file
Open save dialog
select
Open single select file dialog
select_multiple
Open multiple select file dialog