[−][src]Module tauri_api::file
Structs
| Extract | |
| Move | Moves a file from the given path to the specified destination. |
Enums
| ArchiveFormat | |
| Compression |
Functions
| read_binary | |
| read_string |
| Extract | |
| Move | Moves a file from the given path to the specified destination. |
| ArchiveFormat | |
| Compression |
| read_binary | |
| read_string |